<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Zadejte název pro profil.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Takto nazvaný profil už v systému existuje.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Popis umístění repozitáře:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Zvolte umístění Borg repozitáře</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>URL adresa repozitáře:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Vámi zadaný repozitář se nedaří přidat.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Zadejte platnou URL adresu repozitáře nebo vyberte popis umístění v tomto stroji.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Tento repozitář už byl přidán.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Zobrazit moje hesla</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Automaticky vyplněné heslo ze správce hesel.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Skrýt má hesla</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Inicializovat nový repozitář pro zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>URL adresa repozitáře:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Vybrat jako repozitář umístění nacházející se na tomto stroji.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Šifrování:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>SSH klíč:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Zvolit SSH klíč automaticky (výchozí)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Další argumenty pro borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Heslová fráze pro borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Potvrďte zadání heslové fráze:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>Textový štítek</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Archivy pro %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Archivy</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Náhled: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Chyba v šabloně názvu archivu.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Prořezání starších záloh dokončeno.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Znovunačtené archivy.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Zvolte přípojný bod</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Úspěšně připojeno (mount).</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Přípojný bod není aktivní.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Úspěšně odpojeno (unmount).</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="393"/>
        <source>Select an archive to restore first.</source>
        <translation>Nejprve je třeba vybrat archiv, ze kterého obnovit.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="413"/>
        <source>Choose Extraction Point</source>
        <translation>Zvolte bod, do kterého rozbalit</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="478"/>
        <source>Archive deleted.</source>
        <translation>Archiv smazán.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Confirm deletion</source>
        <translation>Potvrďte smazání</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="563"/>
        <source>No archive selected</source>
        <translation>Nevybrán žádný archiv</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Opravdu chcete tento archiv smazat?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="450"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Akce zrušena.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Odpojení se nezdařilo. Ověřte, že {} není využíváno jinými programy</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Nejprve vyberte archiv.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>Change name</source>
        <translation>Změnit název</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>New archive name:</source>
        <translation>Nový název archivu:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="547"/>
        <source>Archive name cannot be blank.</source>
        <translation>Název archivu nemůže zůstat nevyplněný.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="552"/>
        <source>An archive with this name already exists.</source>
        <translation>Takto nazvaný archiv už existuje.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="567"/>
        <source>Archive renamed.</source>
        <translation>Archiv přejmenován.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Archiv znovu načten.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation>Odstraňování zámku repozitáře</translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Zámek repozitáře odstraněn. Zopakujte svou poslední akci.</translation>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation>Spouštění kontroly celistvosti…</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="17"/>
        <source>Check completed.</source>
        <translation>Kontrola dokončena.</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="14"/>
        <source>Repo check failed. See logs for details.</source>
        <translation>Kontrola repozitáře se nezdařila. Podrobnosti naleznete v záznamech událostí.</translation>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>Záloha dokončena s varováními. Podrobnosti naleznete v záznamech událostí.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Záloha dokončena.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Záloha spuštěna.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation>Mazání archivu…</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation>Archiv smazán.</translation>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation>Žádá se o rozdíly mezi archivy…</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>Obdrženy rozdíly mezi archivy.</translation>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation>Stahování souborů z archivu…</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>Soubory obnoveny z archivu.</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation>Znovunačítání archivu</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Znovunačtení archivu dokončeno.</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation>Ověřování existujícího repozitáře…</translation>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation>Nastavování nového repozitáře…</translation>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation>Soubory</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation>Původní</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation>Po sloučení duplicit</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation>Komprimováno</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="299"/>
        <source>Task started</source>
        <translation>Úloha spuštěna</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation>Získávání obsahu archivu…</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>Obsah archivu získán.</translation>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation>Znovunačítání archivů…</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>Znovunačtení archivů dokončeno.</translation>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation>Připojování (mount) archivu do složky…</translation>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation>Prořezávání starších archivů…</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation>Prořezávání dokončeno.</translation>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation>Odpojování (unmount) archivu…</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Archiv:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 z 16. listopadu 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Pozn.: Pokud vyberete složku na vrcholu stromu, pak i když zrušíte výběr jejích podsložek, budou tyto i tak obnoveny.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Rozbalit</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Přidat profil zálohování</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Profily zálohování umožňují jemně členit zálohy z různých zdrojů na různá cílová umsítění. Například je možné zálohovat nejdůležitější dokumenty do vzdáleného repozitáře přes Wifi, zatímco úplné zálohy na zařízení v rámci stroje.&lt;/p&gt;&lt;p&gt;Repozitáře a SSH klíče jsou sdílené napříč profily. Zdrojové složky, aktivní cílové repozitáře, sítě, ze kterých je umožněno, prořezávání starších záloh, ověřování a plánování jsou pro každý z profilů zvlášť.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Název profilu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Vytvořit SSH klíč</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Formát klíče:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Délka klíče:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 nebo 4096 pro RSA, 384 nebo 521 pro ECDSA. Pevné pro Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Více viz&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Výstupní soubor:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Pokud chcete, aby SSH klíč našlo automaticky, pak toto neměňte.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Vytvořit a zkopírovat do schránky</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Vyberte dva archivy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Délka trvání</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Rozdíl</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Rozdíly mezi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Pokud je nastaveno, sdílení tohoto souboru s ostatními odkryje vaší heslovou frázi pro borg. Použijte obezřetně!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Do exportu zahrnout i heslovou frázi k borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Heslová fráze pro borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Přepsat existující profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Přepsat existující nastavení</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Přejmenovat profil</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Připojit se k existujícímu repozitáři</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Zobrazit moje heslo</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Skrýt moje heslo</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Exportovat profil</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Stávající profile_export nemá heslo</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Uložit profile_export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Chyba při exportování</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Soubor {} se nedaří vytvořit. Zvolte jiné umístění.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Profil úspěšně exportován!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Export profilu zapsán do {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Archivy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Délka trvání</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Zkontrolovat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Prořezat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Předvolby prořezávání záloh a pro názvy archivů</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Ponechat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="256"/>
        <source>Use -1 for unlimited.</source>
        <translation>Pro neomezeně použijte -1 (mínus jedna)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="249"/>
        <source> hourly, </source>
        <translation>každou hodinu,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="269"/>
        <source> daily, </source>
        <translation>každý den,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="283"/>
        <source> weekly, </source>
        <translation>každý týden,</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="297"/>
        <source> monthly and</source>
        <translation>každý měsíc a</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="311"/>
        <source> annual archives</source>
        <translation>archivy z každého roku</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Lhostejno jaké, ponechat veškeré archivy za uplynulých:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="348"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24h, 1d, 52t, 12m, 1r</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="388"/>
        <source>Archive Name:</source>
        <translation>Název archivu:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="431"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Proměnné k dispozici: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="398"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{nazev_stroje}-{slug_profilu}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="441"/>
        <source>Prune Prefix:</source>
        <translation>Předpona prořezávání:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Repozitář:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Vyberte umístění zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Odpojit repozitář (toto nesmaže žádná data. Vždy můžete repozitář zase přidat nazpět.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>SSH klíč:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Zkopírovat veřejnou část SSH klíče do schránky.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Pro zabezpečený přístup do vzdálených repozitářů. Pro využití všech vašich už existujících klíčů ponechte výchozí. Nebo vytvořte nový klíč.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Komprese:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Šifrování:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Původní velikost:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Velikost po sloučení duplicit:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Velikost po komprimaci:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="45"/>
        <source>Schedule</source>
        <translation>Naplánovat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="86"/>
        <source>Backup manually</source>
        <translation>Zálohovat ručně</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="143"/>
        <source>Backup every </source>
        <translation>Zálohovat každých</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="110"/>
        <source>Backup daily at</source>
        <translation>Zálohovat každý den v</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="279"/>
        <source>Validate repository data every</source>
        <translation>Ověřit použitelnost dat v repozitáři každých</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="299"/>
        <source>weeks</source>
        <translation>týdnů</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="225"/>
        <source>Prune old Archives after each backup</source>
        <translation>Po každé záloze prořezat starší archivy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Next Backup:</source>
        <translation>Příští záloha:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="345"/>
        <source>Networks</source>
        <translation>Sítě</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="357"/>
        <source>Allowed Networks:</source>
        <translation>Sítě, ze kterých umožněno:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="406"/>
        <source>Log</source>
        <translation>Záznam událostí</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="431"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="436"/>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="441"/>
        <source>Subcommand</source>
        <translation>Dílčí příkaz</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="446"/>
        <source>Repository</source>
        <translation>Repozitář</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="451"/>
        <source>Returncode</source>
        <translation>Návratový kód</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="468"/>
        <source>Shell Commands</source>
        <translation>Příkazy shellu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="477"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Spouštět příkazy shellu před a po provedení každé zálohy. Záloha jako taková a příkazy, prováděné po záloze budou spuštěné pouze tehdy, pokud příkaz pro provedení před zálohou skončí bez chyb (návratový kód 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Příkazy které spouštět PŘED provedením zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="506"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Příkazy, které spouštět PO provedení zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="519"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Proměnné prostředí k dispozici: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Zdrojové složky a soubory, které zálohovat:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Přidat složku</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Pokud jsou přítomny, vynechat (vynechat složky, které obsahují tyto soubory):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Rozdíl</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pro připojování archivů, nejprve nainstalujte „FUSE pro macOS“ &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;odsud&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prořezání probere starší archivy. Je možné zvolit počet archivů za jednotlivé hodiny, dny, atd, které zachovat. Obvykle se ponechává více novějších a méně starších archivů. Přečtěte si &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;více&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Verze vorta:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Nahlásit&lt;/span&gt;&lt;/a&gt; chybu |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Záznam událostí (log)&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Verze borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Repozitář pro zálohy na tomto nebo vzdáleném stroji. Pro jednoduché a zabezpečené hostování zálohy vyzkoušejte &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Komprese je uplatňována na nová data. Je možné změnit a neovlivńuje slučování duplicit. Přečtěte si &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;více&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Vzory pro vynechání (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;více&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Např. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Např. .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Zkopírovat URL adresu repozitáře do schránky</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="364"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Nespouštět zálohování přes sítě s placenými daty</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Přidat soubor(y)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Každá složka nebo soubor na zvlášť řádek</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Vložit složky/soubory</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="434"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{nazev_stroje}-{slug_profilu}-{nyní:%R-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Popis umístění</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Počet souborů</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Přepočítat velikosti</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Vybraný archiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="542"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Při vytváření zálohy přidat tyto argumenty. Podrobnosti naleznete v &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;dokumentaci&lt;/span&gt;&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="558"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Argumenty, které přidat. Např. --dry-run</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="198"/>
        <source>-</source>
        <translation>–</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="252"/>
        <source>Run missed backups right after startup or wakeup</source>
        <translation>Spustit neuskutečněné zálohy hned po spuštění nebo probuzení</translation>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Importovat profil</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Heslová fráze byla načtena ze souboru s exportem</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Heslová fráze byla načtena z vaší klíčenky</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Profil s názvem {} neexistuje. Není co přepsat.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="61"/>
        <source>Error while importing</source>
        <translation>Chyba při importu</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="77"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Aktualizace schématu se nezdařila, vyplňte hlášení chyby s odkazem v panelu Různé s následující chybou:
 {0} 
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Soubory exportu profile_export, vytvořené novější verzí aplikace, nemohou být použity ve starší.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Z důvodu problémů s přístupovými oprávněními není možné číst soubor exportu profile_export.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="84"/>
        <source>Profile export file not found.</source>
        <translation>Soubor s exportem profilu nenalezen.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="255"/>
        <source>Task cancelled</source>
        <translation>Úloha zrušena</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>Hlavní okno</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Stávající profil:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Přejmenovat profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Smazat profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Repozitář</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Zdroje</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Plán</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Archivy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Různé</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Spustit zálohu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Nejnovější</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Restartovat aplikaci</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Přidat profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="163"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Opravdu chcete profil „{}“ smazat?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="164"/>
        <source>Confirm deletion</source>
        <translation>Potvrďte smazání</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="272"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Má Vorta pokračovat v chodu na pozadí?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="277"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Don&apos;t show this again</source>
        <translation>Příště už nezobrazovat</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="83"/>
        <source>Import from file...</source>
        <translation>Importovat ze souboru</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="174"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Není možné smazat poslední zbývající profil.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile import successful!</source>
        <translation>Profil úspěšně naimportován!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} naimportován.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Load profile</source>
        <translation>Načíst profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Všechny soubory (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Exportovat profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Failed to import profile</source>
        <translation>Profil se nepodařilo naimportovat</translation>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ inicializovat nový repozitář</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Přidat existující repozitář</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Nekomprimovat</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Zvolit SSH klíč automaticky (výchozí)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Vytvořit nový klíč</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Veřejná část klíče zkopírována do schránky</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Označená veřejná část SSH klíče byla zkopírována do schránky. Použijte ji pro nastavení oprávnění v repozitáři na protějšku.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Veřejnou část klíče se nedaří najít.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Vyberte veřejnou část klíče z rozbalovací nabídky.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Popojení repozitáře bylo zrušeno</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Vždy ho ale můžete znovu připojit nazpět.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (moderní, výchozí)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard Level 3 (moderní)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard Level 8 (moderní)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB Level 6 (auto, zastaralé)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA Level 6 (auto, zastaralé)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Nejprve z rozbalovací nabídky vyberte repozitář.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (doporučeno)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (zastaralé)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Vysoké (doporučeno)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Soubor s klíčem už existuje. Nebude přepsán.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Nový klíč byl zkopírován do schránky a zapsán do %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Chyba při vytváření klíče.</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="43"/>
        <source>Minutes</source>
        <translation>Minut</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="44"/>
        <source>Hours</source>
        <translation>Hodin</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="45"/>
        <source>Days</source>
        <translation>Dnů</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Weeks</source>
        <translation>Týdnů</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose directory to back up</source>
        <translation>Zvolte složku, kterou zálohovat</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose file(s) to back up</source>
        <translation>Zvolte soubor(y), které zálohovat</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="130"/>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="134"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Výpočet</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="164"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Nemáte přístup pro čtení {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta pro Borg Backup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Přerušit zálohu</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Příští úloha: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Zazálohovat nyní</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation>Úloha probíhá</translation>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Vorta Backup</translation>
    </message>
    <message>
        <location filename="../../application.py" line="191"/>
        <source>No Borg Binary Found</source>
        <translation>Nenalezen žádný spustitelný soubor s nástrojem Borg</translation>
    </message>
    <message>
        <location filename="../../application.py" line="192"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta se nepodařilo nalézt použitelný spustitelný soubor s nástrojem Borg Backup.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>Repository In Use</source>
        <translation>Repozitář je používán něčím jiným</translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Abort</source>
        <translation>Přerušit</translation>
    </message>
    <message>
        <location filename="../../application.py" line="232"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Může být, že repozitář na {repo_url} je právě používán odjinud.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="235"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Zámek rušte pouze pokud jste si naprosto jistí, že žádný další proces nástroje Borg na žádném stroji k repozitáři nepřistupuje. Přerušit nebo pokračovat zrušením zámku?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="243"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Nemáte oprávnění pro přístup k repozitáři na {repo_url}. Získejte přístup a zkuste to znovu.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="246"/>
        <source>No Repository Permissions</source>
        <translation>Žádná oprávnění k repozitáři</translation>
    </message>
    <message>
        <location filename="../../application.py" line="210"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Pro dokončení záloh potřebuje Vorta úplný přístup k disku</translation>
    </message>
    <message>
        <location filename="../../application.py" line="211"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Bez toho některé soubory nebudou přístupné a může to skončit neúplnou zálohou. Nastavte pro Vorta &lt;b&gt;Úplný přístup k disku&lt;/b&gt; v &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Předvolby systému &gt; Zabezpečení a soukromí&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile import successful!</source>
        <translation>Profil úspěšně naimportován!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} naimportován.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import profile</source>
        <translation>Nepodařilo se naimportovat profil</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import a profile from {}:</source>
        <translation>Nepodařilo se naimportovat profil z {}:</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation>Zvažte odebrání nebo opravení tohoto souboru, abyste se zbavili tohoto hlášení.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="295"/>
        <source>Repo Check Failed</source>
        <translation>Kontrola repozitáře se nezdařila</translation>
    </message>
    <message>
        <location filename="../../application.py" line="296"/>
        <source>Repository data check for repo %s failed</source>
        <translation>Kontrola dat repozitáře se v případě repozitáře %s nezdařila</translation>
    </message>
    <message>
        <location filename="../../application.py" line="297"/>
        <source>Repair or recreate the repository soon to avoid missing data.</source>
        <translation>Opravte nebo znovuvytvořte tento repozitář co nejdříve a vyhněte se tak tomu, že budou chybět data.</translation>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="143"/>
        <source>None scheduled</source>
        <translation>Žádné naplánovano</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Vorta Backup</source>
        <translation>Vorta Backup</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="162"/>
        <source>Starting background backup for %s.</source>
        <translation>Spouštění zálohy na pozadí pro %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="184"/>
        <source>Backup successful for %s.</source>
        <translation>Záloha %s úspěšná.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Error during backup creation.</source>
        <translation>Chyba při vytváření zálohy.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Fatální chyba</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Neošetřená výjimka, prosíme vyplňte hlášení s tímto textem na
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Spustitelný soubor s nástrojem Borg nenalezen.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Nejprve přidejte repozitář pro zálohy.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Nejprve do zálohy přidejte nějaké složky.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Fungování na stávající WiFi síti není v nastavení umožněno.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Složka s repozitářem není připojená (mount) nebo byla přesunuta.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Příkaz pro provedení před zálohováním vrátil nenulový ukončovací kód (něco se nezdařilo).</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Spouštění zálohy…</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Nebyly nalezeny žádné aktivní Borg připojení (mount).</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Vámi používaná verze Borg je příliš stará. Je zapotřebí verze 1.1.0 a novější.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Vámi nyní používaná verze Borg nepodporuje ZStd kompresi.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Není spouštěna záloha přes připojení s placenými daty.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Odemkněte svého správce hesel.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Heslo k vámi využívanému repozitáři bylo uloženo ve správci hesel, který už není k dispozici.
Zkuste repozitář odpojit a znovu přidat.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Odemkněte správce hesel systému, nebo vypněte jeho používání aplikací v sekci Různé</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="412"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Je třeba, aby zadání hesla byla identická a delší, než 8 znaků.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="414"/>
        <source>Passwords must be identical.</source>
        <translation>Je třeba, aby zadání hesla byla identická.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="416"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Je třeba, aby heslo bylo delší než 8 znaků.</translation>
    </message>
</context>
</TS>